# -*- coding: utf-8 -*-
"""convert Alphabet to Phonetic Code in English and Japanease."""
from __future__ import unicode_literals


def make_alphabet_dict(p_list):
    return {chr(65 + k): v for k, v in enumerate(p_list) if k < 25}


def make_num_dict(p_list):
    return {str(k): v for k, v in enumerate(p_list) if k < 10}


class A2pcej:
    alphabet_en = [
        'Alfa', 'Bravo', 'Charlie', 'Delta', 'Echo', 'Foxtrot', 'Golf',
        'Hotel', 'India', 'Juliett', 'Kilo', 'Lima', 'Mike', 'November',
        'Oscar', 'Papa', 'Quebec', 'Romeo', 'Sierra', 'Tango', 'Uniform',
        'Victor', 'Whiskey', 'Xray', 'Yankee', 'Zulu'
    ]
    alphabet_ja = [
        'エイ', 'ビー', 'シー', 'ディー', 'イー', 'エフ', 'ジー',
        'エイチ', 'アイ', 'ジェイ', 'ケイ', 'エル', 'エム', 'エヌ',
        'オー', 'ピー', 'キュー', 'アール', 'エス', 'ティー', 'ユー',
        'ヴィー', 'ダブリュー', 'エクス', 'ワイ', 'ゼット',
    ]
    number_en = [
        'zero', 'one', 'two', 'three', 'four', 'five',
        'six', 'seven', 'eight', 'nine',
    ]
    number_ja = [
        'ゼロ', 'イチ', 'ニイ', 'サン', 'ヨン', 'ゴウ',
        'ロク', 'シチ', 'ハチ', 'キュウ',
    ]

    phonetics = {
        'alphabet_en': make_alphabet_dict(alphabet_en),
        'alphabet_ja': make_alphabet_dict(alphabet_ja),
        "number_en": make_num_dict(number_en),
        "number_ja": make_num_dict(number_ja),
    }



# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals
from sys import version_info, exit
import argparse
from .a2pcej import *
"""a2pcej, convert Alphabet to Phonetic Code in English and Japanease.

    This module convert each alphabet letters to phonetic code,
    and also convert each alphabet letterts to katakana.
"""
__all__ = ['conv_al', 'conv_ak']
if version_info[0] == 2:
    __all__ = [n.encode('ascii') for n in __all__]


def main():
    p = argparse.ArgumentParser()
    p.add_argument('-m', '--mode', choices=['en', 'ja'], required=True)
    p.add_argument('-d', '--delimiter')
    p.add_argument('-nd', '--nodelimiter', action='store_true')
    p.add_argument('-s', '--sign')
    p.add_argument('-ns', '--nosign', action='store_true')
    p.add_argument('-n', '--num', action='store_true')
    p.add_argument('letters', nargs='+', type=str)

    args = p.parse_args()

    if args.mode == 'en':
        cmd = conv_al
    else:
        cmd = conv_ak

    if args.delimiter is None and not args.nodelimiter:
        if args.mode == 'en':
            delimiter = '-'
        else:
            delimiter = '・'
    elif args.nodelimiter:
        delimiter = ''
    else:
        delimiter = args.delimiter

    if args.sign is None and not args.nosign:
        if args.mode == 'en':
            sign = '(CAPS)'
        else:
            sign = '（大文字）'
    elif args.nosign:
        sign = ''
    else:
        sign = args.sign

    for s in args.letters:
        print(cmd(s, delimiter=delimiter, sign=sign, num=args.num))


if __name__ == '__main__':
    exit(main())



# -*- coding: utf-8 -*-
"""convert Alphabet to Phonetic Code in English and Japanease."""
from __future__ import absolute_import, unicode_literals
from sys import version_info
from .phonetics import A2pcej


def _converter(phonetics, letters, delimiter, sign, num):
    if version_info[0] == 2:
        letters = letters.decode('utf-8')
    phonetic_dict = A2pcej.phonetics[phonetics]
    phonetic_num_dict = A2pcej.phonetics['number_' + phonetics.split('_')[1]]
    converted_letters = []
    for i in list(letters):
        if i.upper() in phonetic_dict.keys():
            i_phonetic = phonetic_dict[i.upper()]
            if i.isupper():
                i_phonetic += sign
            converted_letters.append(i_phonetic)
        elif (i.isdigit() and num):
            converted_letters.append(phonetic_num_dict[i])
        else:
            converted_letters.append(i)
    return delimiter.join(converted_letters)


def conv_al(letters, delimiter='-', sign='(CAPS)', num=False):
    return _converter('alphabet_en', letters, delimiter, sign, num)


def conv_ak(letters, delimiter='・', sign='（大文字）', num=False):
    return _converter('alphabet_ja', letters, delimiter, sign, num)



# -*- coding: utf-8 -*-
"""A setuptools based setup module.

See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='a2pcej',
    version='0.2.2a3',
    description='''a2pcej, "convert Alphabet to Phonetic Code in English
                   and Japanease."''',
    long_description=long_description,
    url='https://github.com/kacchan822/a2pcej',
    author='Katsuya SAITO',
    author_email='hello@skatsuya.com',
    license='MIT',
    classifiers=[
                    'Development Status :: 3 - Alpha',
                    'Environment :: Console',
                    'Intended Audience :: Developers',
                    'Intended Audience :: System Administrators',
                    'Intended Audience :: Customer Service',
                    'License :: OSI Approved :: MIT License',
                    'Natural Language :: Japanese',
                    'Natural Language :: English',
                    'Operating System :: POSIX',
                    'Programming Language :: Python',
                    'Programming Language :: Python :: 2',
                    'Programming Language :: Python :: 2.7',
                    'Programming Language :: Python :: 3',
                    'Programming Language :: Python :: 3.5',
                    'Topic :: Software Development',
                    'Topic :: Text Processing',
                    'Topic :: Utilities',
                    ],
    keywords='alphabet, katakana, phonetic code',
    packages=find_packages(exclude=['tests', ]),
    install_requires=[],
    entry_points={
                    'console_scripts': ['a2pcej=a2pcej:main',
                                        ],
                },
    )
